=======
Credits
=======

Development Team
----------------

CumulusCI is developed by the Salesforce.org Release Engineering team:

* Jason Lantz <jlantz@salesforce.com>
* Christian Carter <christian.carter@salesforce.com>
* David Glick <dglick@salesforce.com>
* James Estevez <jestevez@salesforce.com>

Developers Emeritus
-------------------

* Chris Polcyn
